import React from "react";

import checkObject from "../../utils/checkObject";

import InputComponent from "../common";
import useForm from "../common/useForm";

const SignIn = props => {
	const form = {
		email: {
			value: "",
			config: {
				type: "email",
				name: "email",
				placeholder: "Enter your email"
			},
			valid: false,
			touch: false,
			validation: {
				required: true
			}
		},
		password: {
			value: "",
			config: {
				type: "password",
				name: "password",
				placeholder: "Enter your password"
			},
			valid: false,
			touch: false,
			validation: {
				required: true,
				minLength: 5
			}
		},
		isValid: false
	};

	const [newObject, { setNew }] = useForm(form);

	const submit = e => {
		e.preventDefault();
		const { auth } = props;
		const values = Object.keys(newObject).reduce(
			(prev, elem) => ({ ...prev, [elem]: newObject[elem].value }),
			{}
		);

		auth(values);
	};

	const change = e => {
		const { name, value } = e.target;
		setNew({ value, name });
	};

	return (
		<form className="auth-box__sign-in-form" onSubmit={submit}>
			{Object.keys(newObject).map(
				el =>
					checkObject(newObject[el]) && (
						<InputComponent
							key={el}
							touch={newObject[el].touch}
							valid={!newObject[el].valid}
							config={{ ...newObject[el].config, value: newObject[el].value, onChange: change }}
						/>
					)
			)}
			<button type="submit">Sign in</button>
		</form>
	);
};

export default SignIn;
